@@ -37,7 +37,7 @@ class ConsumerApp:
         self._bq_table = bq_table
         self._google_creds = google_creds
         self._app = FastAPI()
-        self._is_alive = False
+        self._is_alive = True
         self._is_ready = True
         self.add_endpoints()
         threading.Thread(target=self.read_topic, daemon=True).start()
